@@ -9,5 +9,5 @@ This example shows how to initialize and visualize the vector field
 from pde import CartesianGrid, VectorField
 
 grid = CartesianGrid([[-2, 2], [-2, 2]], 32)
-field = VectorField.from_expression(grid, ['sin(x)', 'cos(x)'])
-field.plot(method='streamplot', title='Stream plot')
+field = VectorField.from_expression(grid, ["sin(x)", "cos(x)"])
+field.plot(method="streamplot", title="Stream plot")
