@@ -673,7 +673,7 @@ class FieldCollection(FieldBase):
 
         # plot all the elements onto the respective axes
         reference = [
-            field.plot(kind=knd, ax=ax, action="create", **kwargs, **sp_args)
+            field.plot(kind=knd, ax=ax, action="none", **kwargs, **sp_args)
             for field, knd, ax, sp_args in zip(  # @UnusedVariable
                 self.fields, kind, axs, subplot_args
             )
