@@ -440,7 +440,7 @@ class Tensor2Field(DataFieldBase):
             data = np.max(self.data, axis=(0, 1))
 
         elif scalar == "squared_sum":
-            data = np.sum(self.data ** 2, axis=(0, 1))
+            data = np.sum(self.data**2, axis=(0, 1))
 
         elif scalar == "norm_squared":
             data = np.sum(self.data * self.data.conjugate(), axis=(0, 1))
@@ -536,7 +536,7 @@ class Tensor2Field(DataFieldBase):
         axs = fig.subplots(nrows=dim, ncols=dim, squeeze=False)
 
         # plot all the elements onto the respective axes
-        kwargs.setdefault("action", "create")
+        kwargs.setdefault("action", "none")
         kwargs["kind"] = kind
         comps = self.grid.axes + self.grid.axes_symmetric
         references = [
