@@ -9,6 +9,7 @@ from __future__ import annotations
 import re
 from typing import Any, Callable, Dict, Tuple
 
+import numba as nb
 import numpy as np
 from numba.typed import Dict as NumbaDict
 from sympy import Symbol
@@ -20,7 +21,7 @@ from ..grids.boundaries.axes import BoundariesData
 from ..grids.boundaries.local import BCDataError
 from ..pdes.base import PDEBase
 from ..tools.docstrings import fill_in_docstring
-from ..tools.numba import jit, nb
+from ..tools.numba import jit
 from ..tools.typing import ArrayLike
 
 
@@ -117,15 +118,7 @@ class PDE(PDEBase):
             rhs = dict(rhs)
         if "t" in rhs:
             raise ValueError("Cannot name field `t` since it denotes time")
-        reserved_symbols = set(rhs) & ScalarExpression._reserved_symbols
-        if any(reserved_symbols):
-            if len(reserved_symbols) == 1:
-                name = reserved_symbols.pop()
-                raise ValueError(f"Cannot use reserved symbol `{name}` as field name")
-            else:
-                raise ValueError(
-                    f"Cannot use reserved symbols {reserved_symbols} as field names"
-                )
+        ScalarExpression.check_reserved_symbols(set(rhs))
         if consts is None:
             consts = {}
 
