@@ -21,7 +21,7 @@ def test_parse_number():
     assert parse_number("-1.4e-5") == pytest.approx(-1.4e-5)
     assert parse_number("sin(3.4)") == pytest.approx(np.sin(3.4))
     assert parse_number("sin(a)", {"a": 3}) == pytest.approx(np.sin(3))
-    assert parse_number("a**b", {"a": 3.2, "b": 4.5}) == pytest.approx(3.2 ** 4.5)
+    assert parse_number("a**b", {"a": 3.2, "b": 4.5}) == pytest.approx(3.2**4.5)
     assert parse_number("1 + 2 * I") == pytest.approx(1 + 2j)
     assert parse_number("a", {"a": 1 + 2j}) == pytest.approx(1 + 2j)
     with pytest.raises(TypeError):
@@ -179,11 +179,15 @@ def test_indexed():
         e.derivatives
 
 
-def test_synonyms():
+def test_synonyms(caplog):
     """test using synonyms in expression"""
-    e = ScalarExpression("2 * all", [["a", "all"]])
+    with caplog.at_level(logging.WARNING):
+        ScalarExpression("2 * a", [["a", "abs"]])
+    assert "abs" in caplog.text
+
+    e = ScalarExpression("2 * arbitrary", [["a", "arbitrary"]])
     assert e.depends_on("a")
-    assert not e.depends_on("all")
+    assert not e.depends_on("arbitrary")
 
 
 def test_tensor_expression():
