@@ -314,7 +314,7 @@ class PlotTracker(TrackerBase):
         self.plot_args = {} if plot_args is None else plot_args.copy()
         # make sure the plot is only create and not shown since the context
         # handles showing the plot itself
-        self.plot_args["action"] = "create"
+        self.plot_args["action"] = "none"
 
         # initialize the movie class
         if movie is None:
